==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PostAuthSessionPolicyRuleAllOfActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PostAuthSessionPolicyRuleAllOfActionsPostAuthSession;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The action to take in response to a failure of the reevaluated global session policy or authentication polices.
 */
@ApiModel(description = "The action to take in response to a failure of the reevaluated global session policy or authentication polices.")
@JsonPropertyOrder({ PostAuthSessionPolicyRuleAllOfActions.JSON_PROPERTY_POST_AUTH_SESSION })
@JsonTypeName("PostAuthSessionPolicyRule_allOf_actions")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PostAuthSessionPolicyRuleAllOfActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POST_AUTH_SESSION = "postAuthSession";
    private PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession;

    public PostAuthSessionPolicyRuleAllOfActions() {
    }

    public PostAuthSessionPolicyRuleAllOfActions postAuthSession(
            PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession) {

        this.postAuthSession = postAuthSession;
        return this;
    }

    /**
     * Get postAuthSession
     *
     * @return postAuthSession
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POST_AUTH_SESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PostAuthSessionPolicyRuleAllOfActionsPostAuthSession getPostAuthSession() {
        return postAuthSession;
    }

    @JsonProperty(JSON_PROPERTY_POST_AUTH_SESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPostAuthSession(PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession) {
        this.postAuthSession = postAuthSession;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PostAuthSessionPolicyRuleAllOfActions postAuthSessionPolicyRuleAllOfActions = (PostAuthSessionPolicyRuleAllOfActions) o;
        return Objects.equals(this.postAuthSession, postAuthSessionPolicyRuleAllOfActions.postAuthSession);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(postAuthSession);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PostAuthSessionPolicyRuleAllOfActions {\n");
        sb.append("    postAuthSession: ").append(toIndentedString(postAuthSession)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PostAuthSessionPolicyRuleAllOfActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PostAuthSessionPolicyRuleAllOfActionsPostAuthSession;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The action to take in response to a failure of the reevaluated global session policy or authentication polices.
 */
@ApiModel(description = "The action to take in response to a failure of the reevaluated global session policy or authentication polices.")
@JsonPropertyOrder({ PostAuthSessionPolicyRuleAllOfActions.JSON_PROPERTY_POST_AUTH_SESSION })
@JsonTypeName("PostAuthSessionPolicyRule_allOf_actions")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PostAuthSessionPolicyRuleAllOfActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_POST_AUTH_SESSION = "postAuthSession";
    private PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession;

    public PostAuthSessionPolicyRuleAllOfActions() {
    }

    public PostAuthSessionPolicyRuleAllOfActions postAuthSession(
            PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession) {

        this.postAuthSession = postAuthSession;
        return this;
    }

    /**
     * Get postAuthSession
     *
     * @return postAuthSession
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_POST_AUTH_SESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PostAuthSessionPolicyRuleAllOfActionsPostAuthSession getPostAuthSession() {
        return postAuthSession;
    }

    @JsonProperty(JSON_PROPERTY_POST_AUTH_SESSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPostAuthSession(PostAuthSessionPolicyRuleAllOfActionsPostAuthSession postAuthSession) {
        this.postAuthSession = postAuthSession;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PostAuthSessionPolicyRuleAllOfActions postAuthSessionPolicyRuleAllOfActions = (PostAuthSessionPolicyRuleAllOfActions) o;
        return Objects.equals(this.postAuthSession, postAuthSessionPolicyRuleAllOfActions.postAuthSession);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(postAuthSession);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PostAuthSessionPolicyRuleAllOfActions {\n");
        sb.append("    postAuthSession: ").append(toIndentedString(postAuthSession)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
